yt.frontends.gadget\_fof.data\_structures module
================================================

.. automodule:: yt.frontends.gadget_fof.data_structures
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
